package com.vernaio.example;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.LineNumberReader;
import java.nio.charset.StandardCharsets;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Optional;

import com.fasterxml.jackson.core.JsonGenerationException;
import com.fasterxml.jackson.core.JsonParseException;
import com.fasterxml.jackson.databind.JsonMappingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.datatype.jdk8.Jdk8Module;
import com.vernaio.aivis.engine.v2.base.sdk.dto.DtoFloatDataPoint;
import com.vernaio.aivis.engine.v2.base.sdk.exception.EngineException;
import com.vernaio.aivis.engine.v2.base.sdk.exception.MissingLibraryException;
import com.vernaio.aivis.engine.v2.base.sdk.exception.WrongFlavourException;
import com.vernaio.aivis.engine.v2.dependency.analysis.sdk.DependencyAnalysisData;

public class Utils {
	
	private static final ObjectMapper MAPPER = new ObjectMapper().registerModule(new Jdk8Module());
	
	public static class FloatSignal {
		
		private final String signalId;
		
		private final List<DtoFloatDataPoint> dataPoints;
		
		protected FloatSignal(final String signalId) {
			this.signalId = signalId;
			this.dataPoints = new ArrayList<DtoFloatDataPoint>();
		}
		
		public List<DtoFloatDataPoint> getDataPoints() {
			return this.dataPoints;
		}
		
		public String getSignalId() {
			return signalId;
		}
	}
	
	public static <T> T readJson(final File file, final Class<T> clazz) throws JsonParseException, JsonMappingException, IOException {
		System.out.println(String.format("\t... reading file '%s' ...", file.getPath()));
		return MAPPER.readValue(file, clazz);
	}
	
	public static <T> void writeJson(final File file, final T obj) throws JsonGenerationException, JsonMappingException, IOException {
		System.out.println(String.format("\t... writing file '%s' ...", file.getPath()));
		Optional.ofNullable(file.getParentFile()).ifPresent(f -> f.mkdirs());
		MAPPER.writeValue(file, obj);
	}
	
}
